# Security Policy

## Supported Versions

Ansible Navigator does not backport security fixes only applying them to the
main branch and making the next patch release in the stream.

## Reporting a Vulnerability

We encourage responsible disclosure practices for security vulnerabilities.
Please read our [policies for reporting bugs] [bug reports policy] if you want
to report a security issue that might affect Ansible.

[bug reports policy]:
  https://docs.ansible.com/ansible/devel/community/reporting_bugs_and_features.html#reporting-a-bug
